#
# spec file for package python-vulture
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-vulture
Version:        1.4
Release:        bp156.3.1
Summary:        Python module for finding dead code
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/jendrikseipp/vulture
Source:         https://files.pythonhosted.org/packages/source/v/vulture/vulture-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest > 3.2.3}
# /SECTION
%python_subpackages

%description
Vulture finds unused code in Python programs. This is useful for
cleaning up and finding errors in code bases. Running Vulture
on both the library and test suite, untested code can be found.

Due to Python's dynamic nature, static code analyzers like Vulture are
likely to miss some dead code. Also, code that is only called implicitly
may be reported as unused.

Features:

* static code analysis
* only one module
* tests itself and has complete test coverage
* complements pyflakes and has the same output syntax
* sorts unused classes and functions by size with ``--sort-by-size``
* supports Python 2.6, 2.7 and 3.x

%prep
%setup -q -n vulture-%{version}
sed -i -e '/^#! \//, 1d' vulture/core.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%python_clone -a %{buildroot}%{_bindir}/vulture

%check
rm setup.cfg
%pytest

%post
%python_install_alternative vulture

%postun
%python_uninstall_alternative vulture

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE.txt
%python_alternative %{_bindir}/vulture
%{python_sitelib}/*

%changelog
* Thu Apr 16 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.4:
  * Ignore unused import statements in __init__.py (RJ722, #192).
  * Report first decorator's line number for unused decorated objects on Python 3.8+ (RJ722, #200).
  * Check code with black and pyupgrade.
* Thu Feb  6 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 1.3
  * Detect redundant ‘if’ conditions without ‘else’ blocks.
  * Add whitelist for string.Formatter
  * Fix tests for Python 3.8
  * Use new Constant AST node under Python 3.8+
  * Add test for f-strings
  * Add whitelist for logging module.
  * Add sys.excepthook to sys whitelist.
  * Add whitelist for ctypes module.
  * Check that type annotations are parsed and type comments are ignored
  * Support checking files with BOM under Python 2.7
* Mon Feb 11 2019 John Vandenberg <jayvdb@gmail.com>
- Update to v1.0
  * Add ``--ignore-decorators`
  * Add whitelist for ``threading`` module
- Add test dependency pytest > 3.2.3 due to use of CaptureResult.
- Reduce hack to remove unsuitable hashbangs
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri Aug 10 2018 jsikes@suse.de
- Update to 0.29
  * Check that NEWS file is up-to-date before releasing
  * Add --ignore-names flag (#139)
  * Add --make-whitelist flag (#135)
  * Single-source package version string (#134)
  * Use absolute imports (#132)
  * Fix PEP8 issues (#120)
* Sun Jul 29 2018 jengelh@inai.de
- Use noun phrase in summary. Trim filler wording from description.
* Thu May 24 2018 toddrme2178@gmail.com
- Spec file cleanups
* Fri Oct 20 2017 toddrme2178@gmail.com
- initial version
